#!/bin/sh
# Description: a little shell script to aid in making ssl certis
# Author: Jason Jorgensen <jasonj@innominatus.com>
# 
# Modify for your needs

if [ -z $1 ]
then
  echo "usage $0 <name of certificate>"
  exit 1
fi

NAME="$1"
OPENSSL=`which openssl`
TAR=`which tar`
DATE=`which date`
CURRENTDATE=`$DATE -u +%m.%d.%Y`

COUNTRY="US"				# Country                             - US, AU, UK, CA
STATE="state"			# State                               - MN, IA, CA, NY
LOCALITY="city"			# City, Town, Village                 - Minneapolis, Mexico City, Moscow
ORGANIZATION="organization"	# Organization, Company, Affiliate    - Joe's Gas Station, The Tortilla Hut, 
UNIT="System Administration"		# Organizational unit, Department     - System Administration, Web Authoring, Administration
COMMONNAME=`hostname --fqdn`		# Common Name, Host name of server    - fully.qualified.domain.name of server hosting
EMAIL="sysadmin@$COMMONNAME"		# Email address of authority for cert - sysadmin@bar.com, theboss@foo.org

#CA="$PASSPHRASE\n$PASSPHRASE\n$COUNTRY\n$STATE\n$LOCALITY\n$ORGANIZATION\n$UNIT\n$COMMONNAME\n$EMAIL\n"
NONCA="$COUNTRY\n$STATE\n$LOCALITY\n$ORGANIZATION\n$UNIT\n$COMMONNAME\n$EMAIL\n\n\n"

#generate some random data for server
dd if=/dev/urandom of=$NAME.rand bs=1024 count=1

$OPENSSL genrsa -rand $NAME.rand -out $NAME.key 1024

echo -e $NONCA | $OPENSSL req -new -key $NAME.key -out $NAME.csr

echo -e $NONCA | $OPENSSL req -new -x509 -nodes -days 730 -in $NAME.csr -out $NAME.pem -keyout $NAME.pem
#openssl req -new -x509 -nodes -days 365 -out stunnel.pem -keyout stunnel.pem
#$OPENSSL x509 -req -days 730 -in $NAME.csr -signkey $NAME.key -out $NAME.pem

chmod 400 stunnel.pem

#$OPENSSL dhparam -rand $NAME.rand 1024 >> $NAME.pem
#$OPENSSL dhparam -rand $NAME.rand 1024 >> $NAME.pem

#Make a backup!
if [ -e "$NAME.pem" ] && [ -e "$NAME.rand" ] && [ -e "$NAME.csr" ] && [ -e "$NAME.key" ]
then
  echo "*** Creation successful! ***"
  tar zcvf $NAME-$CURRENTDATE.tar.gz $NAME.pem $NAME.rand $NAME.key $NAME.csr >/dev/null
  echo "*** BACKUP $NAME-$CURRENTDATE.tar.gz to a floppy disk and store it in a secure place***"
else
  echo "*** Creation FAILED, you will have to troubleshoot ***"
fi

exit;
